#include "dact.h"
#include "config.h"

#if defined(USE_MODULES) && defined(COMP_TEXT_IS_MOD) && !defined(AS_MODULE)
#define comp_text_algo DACT_FAILED_ALGO
#else
int comp_text_algo(int mode, unsigned char *prev_block, unsigned char *curr_block, char *out_block, int blk_size);
int comp_text_compress(unsigned char *prev_block, unsigned char *curr_block, char *out_block, int blk_size);
int comp_text_decompress(unsigned char *prev_block, unsigned char *curr_block, char *out_block, int blk_size);
#endif
